pub struct CodeActionParams {
pub context: CodeActionContext,
pub partial_result_token: Option<ProgressToken>,
pub range: Range,
pub text_document: TextDocumentIdentifier,
pub work_done_token: Option<ProgressToken>,
}Expand description
Params for the CodeActionRequest
Fields
context: CodeActionContextContext carrying additional information.
partial_result_token: Option<ProgressToken>An optional token that a server can use to report partial results (e.g. streaming) to the client.
range: RangeThe range for which the command was invoked.
text_document: TextDocumentIdentifierThe document in which the command was invoked.
work_done_token: Option<ProgressToken>An optional token that a server can use to report work done progress.
Implementations
Sourceimpl CodeActionParams
impl CodeActionParams
Sourcepub fn ret(
result: Vec<OneOf<Command, CodeAction>>,
) -> Vec<OneOf<Command, CodeAction>>
pub fn ret( result: Vec<OneOf<Command, CodeAction>>, ) -> Vec<OneOf<Command, CodeAction>>
helper function for user do not need to remember result type of a request