pub struct ColorPresentationParams {
pub color: Color,
pub partial_result_token: Option<ProgressToken>,
pub range: Range,
pub text_document: TextDocumentIdentifier,
pub work_done_token: Option<ProgressToken>,
}Fields
color: ColorThe color information to request presentations for.
partial_result_token: Option<ProgressToken>An optional token that a server can use to report partial results (e.g. streaming) to the client.
range: RangeThe range where the color would be inserted. Serves as a context.
text_document: TextDocumentIdentifierThe text document.
work_done_token: Option<ProgressToken>An optional token that a server can use to report work done progress.
Implementations
Sourceimpl ColorPresentationParams
impl ColorPresentationParams
Sourcepub fn ret(result: Vec<ColorPresentation>) -> Vec<ColorPresentation>
pub fn ret(result: Vec<ColorPresentation>) -> Vec<ColorPresentation>
helper function for user do not need to remember result type of a request