CompletionItem

Struct CompletionItem 

pub struct CompletionItem {
Show 17 fields pub additional_text_edits: Option<Vec<TextEdit>>, pub command: Option<Command>, pub commit_characters: Option<Vec<String>>, pub data: Option<Value>, pub deprecated: Option<bool>, pub detail: Option<String>, pub documentation: Option<OneOf<String, MarkupContent>>, pub filter_text: Option<String>, pub insert_text: Option<String>, pub insert_text_format: Option<InsertTextFormat>, pub insert_text_mode: Option<InsertTextMode>, pub kind: Option<CompletionItemKind>, pub label: String, pub preselect: Option<bool>, pub sort_text: Option<String>, pub tags: Option<Vec<CompletionItemTag>>, pub text_edit: Option<OneOf<TextEdit, InsertReplaceEdit>>,
}

Fields

additional_text_edits: Option<Vec<TextEdit>>

An optional array of additional text edits that are applied when selecting this completion. Edits must not overlap (including the same insert position) with the main edit nor with themselves.

Additional text edits should be used to change text unrelated to the current cursor position (for example adding an import statement at the top of the file if the completion item will insert an unqualified type).

command: Option<Command>

An optional command that is executed after inserting this completion. Note that additional modifications to the current document should be described with the additionalTextEdits-property.

commit_characters: Option<Vec<String>>

An optional set of characters that when pressed while this completion is active will accept it first and then type that character. Note that all commit characters should have length=1 and that superfluous characters will be ignored.

data: Option<Value>

A data entry field that is preserved on a completion item between a completion and a completion resolve request.

deprecated: Option<bool>

Indicates if this item is deprecated.

detail: Option<String>

A human-readable string with additional information about this item, like type or symbol information.

documentation: Option<OneOf<String, MarkupContent>>

A human-readable string that represents a doc-comment.

filter_text: Option<String>

A string that should be used when filtering a set of completion items. When falsy the label is used as the filter text for this item.

insert_text: Option<String>

A string that should be inserted into a document when selecting this completion. When falsy the label is used as the insert text for this item.

The insertText is subject to interpretation by the client side. Some tools might not take the string literally. For example VS Code when code complete is requested in this example con<cursor position> and a completion item with an insertText of console is provided it will only insert sole. Therefore it is recommended to use textEdit instead since it avoids additional client side interpretation.

insert_text_format: Option<InsertTextFormat>

The format of the insert text. The format applies to both the insertText property and the newText property of a provided textEdit. If omitted defaults to InsertTextFormat.PlainText.

insert_text_mode: Option<InsertTextMode>

How whitespace and indentation is handled during completion item insertion. If not provided the client’s default value is used.

kind: Option<CompletionItemKind>

The kind of this completion item. Based of the kind an icon is chosen by the editor. The standardized set of available values is defined in CompletionItemKind.

label: String

The label of this completion item. By default also the text that is inserted when selecting this completion.

preselect: Option<bool>

Select this item when showing.

Note that only one completion item can be selected and that the tool / client decides which item that is. The rule is that the first item of those that match best is selected.

sort_text: Option<String>

A string that should be used when comparing this item with other items. When falsy the label is used as the sort text for this item.

tags: Option<Vec<CompletionItemTag>>

Tags for this completion item.

text_edit: Option<OneOf<TextEdit, InsertReplaceEdit>>

An edit which is applied to a document when selecting this completion. When an edit is provided the value of insertText is ignored.

Note: The range of the edit must be a single line range and it must contain the position at which completion has been requested.

Most editors support two different operations when accepting a completion item. One is to insert a completion text and the other is to replace an existing text with a completion text. Since this can usually not be predetermined by a server it can report both ranges. Clients need to signal support for InsertReplaceEdits via the textDocument.completion.insertReplaceSupport client capability property.

Note 1: The text edit’s range as well as both ranges from an insert replace edit must be a [single line] and they must contain the position at which completion has been requested. Note 2: If an InsertReplaceEdit is returned the edit’s insert range must be a prefix of the edit’s replace range, that means it must be contained and starting at the same position.

Implementations

Source

impl CompletionItem

pub fn ret(result: CompletionItem) -> CompletionItem

helper function for user do not need to remember result type of a request