pub struct DeclarationParams {
pub partial_result_token: Option<ProgressToken>,
pub position: Position,
pub text_document: TextDocumentIdentifier,
pub work_done_token: Option<ProgressToken>,
}Fields
partial_result_token: Option<ProgressToken>An optional token that a server can use to report partial results (e.g. streaming) to the client.
position: PositionThe position inside the text document.
text_document: TextDocumentIdentifierThe text document.
work_done_token: Option<ProgressToken>An optional token that a server can use to report work done progress.
Implementations