pub struct DeclarationRegistrationOptions {
pub document_selector: Value,
pub id: Option<String>,
pub work_done_progress: Option<bool>,
}Fields
document_selector: ValueA document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
id: Option<String>The id used to register the request. The id can be used to deregister the request again. See also Registration#id.
work_done_progress: Option<bool>Trait Implementations
Sourceimpl Clone for DeclarationRegistrationOptions
impl Clone for DeclarationRegistrationOptions
Sourcefn clone(&self) -> DeclarationRegistrationOptions
fn clone(&self) -> DeclarationRegistrationOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DeclarationRegistrationOptions
impl Default for DeclarationRegistrationOptions
Sourcefn default() -> DeclarationRegistrationOptions
fn default() -> DeclarationRegistrationOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DeclarationRegistrationOptions
impl<'de> Deserialize<'de> for DeclarationRegistrationOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DeclarationRegistrationOptions
impl PartialEq for DeclarationRegistrationOptions
Sourcefn eq(&self, other: &DeclarationRegistrationOptions) -> bool
fn eq(&self, other: &DeclarationRegistrationOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeclarationRegistrationOptions