DocumentSymbolClientCapabilities

Struct DocumentSymbolClientCapabilities 

pub struct DocumentSymbolClientCapabilities {
    pub dynamic_registration: Option<bool>,
    pub hierarchical_document_symbol_support: Option<bool>,
    pub label_support: Option<bool>,
    pub symbol_kind: Option<DocumentSymbolClientCapabilitiesSymbolKind>,
    pub tag_support: Option<DocumentSymbolClientCapabilitiesTagSupport>,
}

Fields

dynamic_registration: Option<bool>

Whether document symbol supports dynamic registration.

hierarchical_document_symbol_support: Option<bool>

The client supports hierarchical document symbols.

label_support: Option<bool>

The client supports an additional label presented in the UI when registering a document symbol provider.

symbol_kind: Option<DocumentSymbolClientCapabilitiesSymbolKind>

Specific capabilities for the SymbolKind in the textDocument/documentSymbol request.

tag_support: Option<DocumentSymbolClientCapabilitiesTagSupport>

The client supports tags on SymbolInformation. Tags are supported on DocumentSymbol if hierarchicalDocumentSymbolSupport is set to true. Clients supporting tags have to handle unknown tags gracefully.