FoldingRangeClientCapabilities

Struct FoldingRangeClientCapabilities 

pub struct FoldingRangeClientCapabilities {
    pub dynamic_registration: Option<bool>,
    pub line_folding_only: Option<bool>,
    pub range_limit: Option<Uinteger>,
}

Fields

dynamic_registration: Option<bool>

Whether implementation supports dynamic registration for folding range providers. If this is set to true the client supports the new FoldingRangeRegistrationOptions return value for the corresponding server capability as well.

line_folding_only: Option<bool>

If set, the client signals that it only supports folding complete lines. If set, client will ignore specified startCharacter and endCharacter properties in a FoldingRange.

range_limit: Option<Uinteger>

The maximum number of folding ranges that the client prefers to receive per document. The value serves as a hint, servers are free to follow the limit.