pub struct LocationLink {
pub origin_selection_range: Option<Range>,
pub target_range: Range,
pub target_selection_range: Range,
pub target_uri: DocumentUri,
}Fields
origin_selection_range: Option<Range>Span of the origin of this link.
Used as the underlined span for mouse interaction. Defaults to the word range at the mouse position.
target_range: RangeThe full target range of this link. If the target for example is a symbol then target range is the range enclosing this symbol not including leading/trailing whitespace but everything else like comments. This information is typically used to highlight the range in the editor.
target_selection_range: RangeThe range that should be selected and revealed when this link is being followed, e.g the
name of a function. Must be contained by the the targetRange. See also
DocumentSymbol#range
target_uri: DocumentUriThe target resource identifier of this link.