pub struct TextDocumentSyncOptions {
pub change: Option<TextDocumentSyncKind>,
pub open_close: Option<bool>,
pub will_save: Option<bool>,
pub will_save_until: Option<bool>,
pub save: Option<OneOf<bool, SaveOptions>>,
}Fields
change: Option<TextDocumentSyncKind>Change notifications are sent to the server. See TextDocumentSyncKind.None, TextDocumentSyncKind.Full and TextDocumentSyncKind.Incremental. If omitted it defaults to TextDocumentSyncKind.None.
open_close: Option<bool>Open and close notifications are sent to the server. If omitted open close notification should not be sent.
will_save: Option<bool>If present will save notifications are sent to the server. If omitted the notification should not be sent.
will_save_until: Option<bool>If present will save notifications are sent to the server. If omitted the notification should not be sent.
save: Option<OneOf<bool, SaveOptions>>If present save notifications are sent to the server. If omitted the notification should not be sent.