pub struct TypeDefinitionRegistrationOptions {
pub document_selector: Value,
pub id: Option<String>,
pub work_done_progress: Option<bool>,
}Fields
document_selector: ValueA document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.
id: Option<String>The id used to register the request. The id can be used to deregister the request again. See also Registration#id.
work_done_progress: Option<bool>Trait Implementations
Sourceimpl Clone for TypeDefinitionRegistrationOptions
impl Clone for TypeDefinitionRegistrationOptions
Sourcefn clone(&self) -> TypeDefinitionRegistrationOptions
fn clone(&self) -> TypeDefinitionRegistrationOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TypeDefinitionRegistrationOptions
impl<'de> Deserialize<'de> for TypeDefinitionRegistrationOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TypeDefinitionRegistrationOptions
impl PartialEq for TypeDefinitionRegistrationOptions
Sourcefn eq(&self, other: &TypeDefinitionRegistrationOptions) -> bool
fn eq(&self, other: &TypeDefinitionRegistrationOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TypeDefinitionRegistrationOptions