pub struct WorkspaceFoldersServerCapabilities {
pub change_notifications: Option<OneOf<bool, String>>,
pub supported: Option<bool>,
}Fields
change_notifications: Option<OneOf<bool, String>>Whether the server wants to receive workspace folder change notifications.
If a string is provided, the string is treated as an ID under which the notification is
registered on the client side. The ID can be used to unregister for these events using the
client/unregisterCapability request.
supported: Option<bool>The server has support for workspace folders